import type { Actions } from './$types';
import { env } from '$env/dynamic/private';
import { building } from '$app/environment';
import { Blob } from 'node:buffer';

export const actions = {
	submitFeedback: async (event) => {
        try {
            const fd = await event.request.formData();
            const feedback = fd.get("feedback");
            const context = fd.get("context") || "{}";
            console.log(feedback, context);

            const ip = event.getClientAddress(); 

            const formData = new FormData();
            formData.append('file', new Blob([JSON.stringify(JSON.parse(context), null, 2)], { type: 'application/json' }), `chatHistory_${new Date().toISOString()}.json`);
            formData.append('payload_json', JSON.stringify({
                embeds: [{
                    title: "New Feedback Received",
                    description: `${feedback}`,
                    color: 0x00ff00,
                    timestamp: new Date().toISOString(),
                    footer: {
                        "text": ip
                    }
                }]
            }));

            const webhookUrl = env.WEBHOOK;
            if (!webhookUrl) {
                console.error("WEBHOOK URL is not defined");
                return { success: false };
            }
            
            if (!building) {
                await fetch(webhookUrl, {
                    method: 'POST',
                    body: formData,
                });
            }

            return {
                success: true,
            };
        } catch (e) {
            console.error(e);
            return {
                success: false,
            };
        }
	}
} satisfies Actions;